#! /usr/bin/env python
## -*- coding: iso-8859-1 -*-
## vi:ts=4:et
##
##---------------------------------------------------------------------------##
##
## python-stablesort -- an adaptive, stable, natural mergesort
##
## http://py-stablesort.sourceforge.net/
##
## Wrapper code Copyright (C) 2002-2003 Markus F.X.J. Oberhumer.
##
## Actual sort implementation Copyright (C) 2002-2003 the
## Python Software Foundation. Written by Tim Peters.
##
## Distributed under the terms of the PSF License Agreement - see the
## file LICENSE.
##
##---------------------------------------------------------------------------##

PACKAGE = "python-stablesort"
VERSION = "1.2.2"

import os, sys
import distutils
from distutils.core import setup
from distutils.extension import Extension
from distutils.util import split_quoted
from distutils.version import LooseVersion

include_dirs = []
define_macros = []
library_dirs = []
libraries = []
runtime_library_dirs = []
extra_objects = []
extra_compile_args = []
extra_link_args = []


###############################################################################

def get_kw(**kw): return kw

ext = Extension(
    name="stablesort",
    sources=[os.path.join("src", "stablesort.c"),],
    include_dirs=include_dirs,
    define_macros=define_macros,
    library_dirs=library_dirs,
    libraries=libraries,
    runtime_library_dirs=runtime_library_dirs,
    extra_objects=extra_objects,
    extra_compile_args=extra_compile_args,
    extra_link_args=extra_link_args,
)
##print ext.__dict__; sys.exit(1)


if sys.platform == "win32":
    datadir = os.path.join("doc", PACKAGE)
else:
    datadir = os.path.join("share", "doc", PACKAGE)

setup_args = get_kw(
    name=PACKAGE,
    version=VERSION,
    description="Stable sort a list in-place",
    author="Markus F.X.J. Oberhumer (wrapper), Tim Peters (actual sort implementation)",
    author_email="mfx@users.sourceforge.net",
    url="http://py-stablesort.sourceforge.net/",
    license="Python PSF License Agreement",
    ext_modules=[ext],
    data_files = [
        # list of tuples with (path to install to, a list of files)
        (datadir, [
            "INSTALL", "LICENSE", "NEWS", "README", "TODO", "listsort.txt",
        ]),
    ],
    long_description="""
python-stablesort -- an adaptive, stable, natural mergesort.

python-stablesort is a back-port of the new Python CVS stable listsort
algorithm to all Python versions (from 1.5.2 to 2.2.3).

It can also be regarded as some sort of forward-port in case the default
Python list.sort() method will change to an non-stable sort behavior again.""",
)

##print distutils.__version__
if LooseVersion(distutils.__version__) > LooseVersion("1.0.1"):
    setup_args["platforms"] = "All"
if LooseVersion(distutils.__version__) < LooseVersion("1.0.3"):
    setup_args["licence"] = setup_args["license"]

apply(setup, (), setup_args)

